@@ -15,7 +15,7 @@ use Mozilla::CA;
 use Scalar::Util;
 use XML::LibXML;
 
-our $VERSION = '1.0.3';
+our $VERSION = '1.0.4';
 
 use constant ENDPOINTS => {
     'IMGUR'           => 'https://api.imgur.com/3',
@@ -88,7 +88,8 @@ sub request {
     # Extract rate limit headers
     my @ratelimit_headers = qw(userlimit userremaining userreset clientlimit clientremaining);
     foreach my $header (@ratelimit_headers) {
-        $self->{'ratelimit_hdrs'}->{$header} = $response->header("x-ratelimit-$header");
+        my $val = $response->header("x-ratelimit-$header");
+        $self->{'ratelimit_headers'}->{$header} = $val && $val =~ /^\d+$/ ? int $val : $val;
     }
 
     # Store response content
@@ -973,17 +974,73 @@ A getter and setter method is provided for each constructor arg.
 
     $response = $client->response;
 
+This method will return the last response object from the last request.
+
 =head4 response_content
 
     $response_content = $client->response_content;
 
+This method will return the last response content from the last request.
+
 =head4 ratelimit_headers
 
     $ratelimit_headers = $client->ratelimit_headers;
 
+This method will return a hashref containing the rate limit headers from the last request. The keys returned are:
+
+=over 4
+
+=item *
+
+C<userlimit> - The total credits that can be allocated.
+
+=item *
+
+C<userremaining> - The total credits remaining.
+
+=item *
+
+C<userreset> - Timestamp (unix epoch) for when the credits will be reset.
+
+=item *
+
+C<clientlimit> - Total credits that can be allocated for the application in a day.
+
+=item *
+
+C<clientremaining> - Total credits remaining for the application in a day.
+
+=back
+
+
 =head3 API REQUEST METHODS
 
 
+=head4 ACCOUNT
+
+=head5 account
+
+    $account = $client->account('username');
+
+Get account information for a given username. Pass C<me> as the username to get the account information for the authenticated user.
+
+=head5 account_album
+
+    $album = $client->account_album('username', 'album_id');
+
+Get information about a specific account album. Pass C<me> as the username to get the account information for the authenticated user.
+
+=head4 ALBUM
+
+=head4 COMMENT
+
+=head4 GALLERY
+
+=head4 IMAGE
+
+=head4 FEED
+
+
 =head1 AUTHOR
 
 Dillan Hildebrand
